@@ -3,11 +3,12 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,16 +18,18 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('autofit01.xlsx')
+        self.set_filename("autofit01.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
 
         workbook = Workbook(self.got_filename)
-
         worksheet = workbook.add_worksheet()
 
+        # Before writing data, nothing to autofit (should not raise)
+        worksheet.autofit()
+
+        # Write something that can be autofit
         worksheet.write_string(0, 0, "A")
 
         # Check for handling default/None width.
