@@ -3,13 +3,15 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
-from ...workbook import Workbook
 from io import BytesIO
 
+from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
+
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
     """
@@ -18,8 +20,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('background02.xlsx')
+        self.set_filename("background02.xlsx")
 
     def test_create_file(self):
         """Test the creation of an XlsxWriter file with a background image."""
@@ -28,7 +29,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.set_background(self.image_dir + 'logo.jpg')
+        worksheet.set_background(self.image_dir + "logo.jpg")
 
         workbook.close()
 
@@ -41,11 +42,10 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        image_file = open(self.image_dir + 'logo.jpg', 'rb')
-        image_data = BytesIO(image_file.read())
-        image_file.close()
+        with open(self.image_dir + "logo.jpg", "rb") as image_file:
+            image_data = BytesIO(image_file.read())
 
-        worksheet.set_background(image_data, is_byte_stream=True)
+        worksheet.set_background(image_data)
 
         workbook.close()
 
