@@ -3,11 +3,12 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +18,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('chart_legend05.xlsx')
+        self.set_filename("chart_legend05.xlsx")
 
     def test_create_file(self):
         """Test the creation of an XlsxWriter file with legend options."""
@@ -26,7 +26,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
-        chart = workbook.add_chart({'type': 'line'})
+        chart = workbook.add_chart({"type": "line"})
 
         chart.axis_ids = [79973376, 84140800]
 
@@ -36,17 +36,17 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
             [3, 6, 9, 12, 15],
         ]
 
-        worksheet.write_column('A1', data[0])
-        worksheet.write_column('B1', data[1])
-        worksheet.write_column('C1', data[2])
+        worksheet.write_column("A1", data[0])
+        worksheet.write_column("B1", data[1])
+        worksheet.write_column("C1", data[2])
 
-        chart.add_series({'values': '=Sheet1!$A$1:$A$5'})
-        chart.add_series({'values': '=Sheet1!$B$1:$B$5'})
-        chart.add_series({'values': '=Sheet1!$C$1:$C$5'})
+        chart.add_series({"values": "=Sheet1!$A$1:$A$5"})
+        chart.add_series({"values": "=Sheet1!$B$1:$B$5"})
+        chart.add_series({"values": "=Sheet1!$C$1:$C$5"})
 
-        chart.set_legend({'border': {'color': '#4F81BD'}})
+        chart.set_legend({"border": {"color": "#4F81BD"}})
 
-        worksheet.insert_chart('E9', chart)
+        worksheet.insert_chart("E9", chart)
 
         workbook.close()
 
