@@ -3,11 +3,12 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +18,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('chart_points01.xlsx')
+        self.set_filename("chart_points01.xlsx")
 
     def test_create_file(self):
         """Test the creation of an XlsxWriter file with point formatting."""
@@ -26,18 +26,20 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
-        chart = workbook.add_chart({'type': 'pie'})
+        chart = workbook.add_chart({"type": "pie"})
 
         data = [2, 5, 4, 1, 7, 4]
 
-        worksheet.write_column('A1', data)
+        worksheet.write_column("A1", data)
 
-        chart.add_series({
-            'values': '=Sheet1!$A$1:$A$6',
-            'points': [{'fill': {'color': 'red'}}],
-        })
+        chart.add_series(
+            {
+                "values": "=Sheet1!$A$1:$A$6",
+                "points": [{"fill": {"color": "red"}}],
+            }
+        )
 
-        worksheet.insert_chart('E9', chart)
+        worksheet.insert_chart("E9", chart)
 
         workbook.close()
 
