@@ -3,10 +3,11 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
 #
-from ..excel_comparison_test import ExcelComparisonTest
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
+#
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -16,8 +17,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('data_validation07.xlsx')
+        self.set_filename("data_validation07.xlsx")
 
     def test_create_file(self):
         """Test the creation of a XlsxWriter file with data validation."""
@@ -27,9 +27,11 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         worksheet = workbook.add_worksheet()
 
         worksheet.data_validation(
-            'C2', {'validate': 'list',
-                   'value': ['coffee', 'café'],
-                   }
+            "C2",
+            {
+                "validate": "list",
+                "value": ["coffee", "café"],
+            },
         )
 
         workbook.close()
