@@ -3,11 +3,12 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +18,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('default_row04.xlsx')
+        self.set_filename("default_row04.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -29,12 +29,12 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet.set_default_row(24)
 
-        worksheet.write('A1', 'Foo')
-        worksheet.write('A10', 'Bar')
+        worksheet.write("A1", "Foo")
+        worksheet.write("A10", "Bar")
 
-        worksheet.write_comment('C4', 'Hello', {'y_offset': 22})
+        worksheet.write_comment("C4", "Hello", {"y_offset": 22})
 
-        worksheet.set_comments_author('John')
+        worksheet.set_comments_author("John")
 
         workbook.close()
 
