@@ -3,11 +3,12 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +18,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('escapes02.xlsx')
+        self.set_filename("escapes02.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with comments.Check encoding of comments."""
@@ -27,8 +27,8 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.write('A1', '"<>\'&')
-        worksheet.write_comment('B2', """<>&"'""")
+        worksheet.write("A1", "\"<>'&")
+        worksheet.write_comment("B2", """<>&"'""")
 
         worksheet.set_comments_author("""I am '"<>&""")
 
