@@ -3,11 +3,12 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +18,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('format14.xlsx')
+        self.set_filename("format14.xlsx")
 
     def test_create_file(self):
         """Test the center across format."""
@@ -30,7 +30,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         center.set_center_across()
 
-        worksheet.write('A1', 'foo', center)
+        worksheet.write("A1", "foo", center)
 
         workbook.close()
 
@@ -44,7 +44,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         worksheet = workbook.add_worksheet()
         center = workbook.add_format({"center_across": True})
 
-        worksheet.write('A1', 'foo', center)
+        worksheet.write("A1", "foo", center)
 
         workbook.close()
 
