@@ -3,11 +3,12 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,11 +18,12 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
+        self.set_filename("header_image06.xlsx")
 
-        self.set_filename('header_image06.xlsx')
-
-        self.ignore_elements = {'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup'],
-                                'xl/worksheets/sheet2.xml': ['<pageMargins', '<pageSetup']}
+        self.ignore_elements = {
+            "xl/worksheets/sheet1.xml": ["<pageMargins", "<pageSetup"],
+            "xl/worksheets/sheet2.xml": ["<pageMargins", "<pageSetup"],
+        }
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with image(s)."""
@@ -31,11 +33,9 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         worksheet1 = workbook.add_worksheet()
         worksheet2 = workbook.add_worksheet()
 
-        worksheet1.set_header('&L&G',
-                              {'image_left': self.image_dir + 'red.jpg'})
+        worksheet1.set_header("&L&G", {"image_left": self.image_dir + "red.jpg"})
 
-        worksheet2.set_header('&L&G',
-                              {'image_left': self.image_dir + 'blue.jpg'})
+        worksheet2.set_header("&L&G", {"image_left": self.image_dir + "blue.jpg"})
 
         workbook.close()
 
