@@ -3,11 +3,12 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,11 +18,15 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('hyperlink16.xlsx')
+        self.set_filename("hyperlink16.xlsx")
 
     def test_create_file(self):
-        """Test the creation of a simple XlsxWriter file with hyperlinks.This example doesn't have any link formatting and tests the relationship linkage code."""
+        """
+        Test the creation of a simple XlsxWriter file with hyperlinks. This
+        example doesn't have any link formatting and tests the relationship
+        linkage code.
+
+        """
 
         workbook = Workbook(self.got_filename)
 
@@ -30,7 +35,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.write_url('B2', 'external:./subdir/blank.xlsx')
+        worksheet.write_url("B2", "external:./subdir/blank.xlsx")
 
         workbook.close()
 
