@@ -3,13 +3,15 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
-from ...workbook import Workbook
 from io import BytesIO
 
+from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
+
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
     """
@@ -18,8 +20,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('image03.xlsx')
+        self.set_filename("image03.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with image(s)."""
@@ -28,11 +29,10 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        image_file = open(self.image_dir + 'red.jpg', 'rb')
-        image_data = BytesIO(image_file.read())
-        image_file.close()
+        with open(self.image_dir + "red.jpg", "rb") as image_file:
+            image_data = BytesIO(image_file.read())
 
-        worksheet.insert_image('E9', 'red.jpg', {'image_data': image_data})
+        worksheet.insert_image("E9", "red.jpg", {"image_data": image_data})
 
         workbook.close()
 
