@@ -3,11 +3,12 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +18,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('macro02.xlsm')
+        self.set_filename("macro02.xlsm")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -27,11 +27,11 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        workbook.add_vba_project(self.vba_dir + 'vbaProject03.bin')
-        workbook.set_vba_name('MyWorkbook')
-        worksheet.set_vba_name('MySheet1')
+        workbook.add_vba_project(self.vba_dir + "vbaProject03.bin")
+        workbook.set_vba_name("MyWorkbook")
+        worksheet.set_vba_name("MySheet1")
 
-        worksheet.write('A1', 123)
+        worksheet.write("A1", 123)
 
         workbook.close()
 
