@@ -3,11 +3,12 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +18,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('object_position12.xlsx')
+        self.set_filename("object_position12.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with image(s)."""
@@ -29,7 +29,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet.set_column(1, 1, 5, None)
 
-        worksheet.insert_image('E9', self.image_dir + 'red.png')
+        worksheet.insert_image("E9", self.image_dir + "red.png")
 
         workbook.close()
 
