@@ -3,11 +3,12 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +18,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('properties03.xlsx')
+        self.set_filename("properties03.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -27,10 +27,13 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        workbook.set_custom_property('Checked by', 'Adam')
+        workbook.set_custom_property("Checked by", "Adam")
 
-        worksheet.set_column('A:A', 70)
-        worksheet.write('A1', "Select 'Office Button -> Prepare -> Properties' to see the file properties.")
+        worksheet.set_column("A:A", 70)
+        worksheet.write(
+            "A1",
+            "Select 'Office Button -> Prepare -> Properties' to see the file properties.",
+        )
 
         workbook.close()
 
