@@ -3,11 +3,12 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +18,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('rich_string10.xlsx')
+        self.set_filename("rich_string10.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -27,13 +27,13 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        bold = workbook.add_format({'bold': 1})
-        italic = workbook.add_format({'italic': 1})
+        bold = workbook.add_format({"bold": 1})
+        italic = workbook.add_format({"italic": 1})
 
-        worksheet.write('A1', 'Foo', bold)
-        worksheet.write('A2', 'Bar', italic)
+        worksheet.write("A1", "Foo", bold)
+        worksheet.write("A2", "Bar", italic)
 
-        worksheet.write_rich_string('A3', ' a', bold, 'bc', 'defg ')
+        worksheet.write_rich_string("A3", " a", bold, "bc", "defg ")
 
         workbook.close()
 
