@@ -3,11 +3,12 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +18,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('rich_string12.xlsx')
+        self.set_filename("rich_string12.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -27,17 +27,19 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.set_column('A:A', 30)
+        worksheet.set_column("A:A", 30)
         worksheet.set_row(2, 60)
 
-        bold = workbook.add_format({'bold': 1})
-        italic = workbook.add_format({'italic': 1})
-        wrap = workbook.add_format({'text_wrap': 1})
+        bold = workbook.add_format({"bold": 1})
+        italic = workbook.add_format({"italic": 1})
+        wrap = workbook.add_format({"text_wrap": 1})
 
-        worksheet.write('A1', 'Foo', bold)
-        worksheet.write('A2', 'Bar', italic)
+        worksheet.write("A1", "Foo", bold)
+        worksheet.write("A2", "Bar", italic)
 
-        worksheet.write_rich_string('A3', "This is\n", bold, "bold\n", "and this is\n", italic, 'italic', wrap)
+        worksheet.write_rich_string(
+            "A3", "This is\n", bold, "bold\n", "and this is\n", italic, "italic", wrap
+        )
 
         workbook.close()
 
