@@ -3,11 +3,12 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +18,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('set_row03.xlsx')
+        self.set_filename("set_row03.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file."""
@@ -38,7 +38,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         worksheet.set_row_pixels(14, 15)
 
         worksheet.set_row_pixels(18, 19)
-        worksheet.set_row_pixels(20, 21, None, {'hidden': True})
+        worksheet.set_row_pixels(20, 21, None, {"hidden": True})
         worksheet.set_row_pixels(21, 22)
 
         workbook.close()
