@@ -3,11 +3,12 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,10 +18,9 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
+        self.set_filename("textbox32.xlsx")
 
-        self.set_filename('textbox32.xlsx')
-
-        self.ignore_elements = {'xl/drawings/drawing1.xml': ['<a:fld']}
+        self.ignore_elements = {"xl/drawings/drawing1.xml": ["<a:fld"]}
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with textbox(s)."""
@@ -30,7 +30,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         worksheet1 = workbook.add_worksheet()
         worksheet2 = workbook.add_worksheet()
 
-        worksheet1.insert_textbox('E9', '', {'textlink': '=Sheet2!A1'})
+        worksheet1.insert_textbox("E9", "", {"textlink": "=Sheet2!A1"})
 
         workbook.close()
 
