@@ -3,11 +3,12 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
 from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +18,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('textbox37.xlsx')
+        self.set_filename("textbox37.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with textbox(s)."""
@@ -27,9 +27,11 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.insert_textbox('E9', 'This is some text',
-                                 {'url': 'https://github.com/jmcnamara',
-                                  'tip': 'GitHub'})
+        worksheet.insert_textbox(
+            "E9",
+            "This is some text",
+            {"url": "https://github.com/jmcnamara", "tip": "GitHub"},
+        )
 
         workbook.close()
 
