@@ -3,16 +3,18 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ..excel_comparison_test import ExcelComparisonTest
-from ...workbook import Workbook
 import uuid
 
+from ...workbook import Workbook
+from ..excel_comparison_test import ExcelComparisonTest
 
-def write_uuid(worksheet, row, col, token, format=None):
-    return worksheet.write_string(row, col, str(token), format)
+
+def write_uuid(worksheet, row, col, token, cell_format=None):
+    return worksheet.write_string(row, col, str(token), cell_format)
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -22,8 +24,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('types10.xlsx')
+        self.set_filename("types10.xlsx")
 
     def test_write_user_type(self):
         """Test writing numbers as text."""
@@ -32,9 +33,9 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         worksheet = workbook.add_worksheet()
 
         worksheet.add_write_handler(uuid.UUID, write_uuid)
-        my_uuid = uuid.uuid3(uuid.NAMESPACE_DNS, 'python.org')
+        my_uuid = uuid.uuid3(uuid.NAMESPACE_DNS, "python.org")
 
-        worksheet.write('A1', my_uuid)
+        worksheet.write("A1", my_uuid)
 
         workbook.close()
 
