@@ -3,13 +3,15 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
 import unittest
 from io import StringIO
-from ...styles import Styles
+
 from ...format import Format
+from ...styles import Styles
 
 
 class TestWriteNumFmts(unittest.TestCase):
@@ -28,13 +30,15 @@ class TestWriteNumFmts(unittest.TestCase):
 
         xf_format = Format()
         xf_format.num_format_index = 164
-        xf_format.set_num_format('#,##0.0')
+        xf_format.set_num_format("#,##0.0")
 
-        self.styles._set_style_properties([[xf_format], None, 0, 1, 0, 0, [], [], 0])
+        self.styles._set_style_properties(
+            [[xf_format], None, 0, ["#,##0.0"], 0, 0, [], [], 0]
+        )
 
         self.styles._write_num_fmts()
 
         exp = """<numFmts count="1"><numFmt numFmtId="164" formatCode="#,##0.0"/></numFmts>"""
         got = self.fh.getvalue()
 
-        self.assertEqual(got, exp)
+        self.assertEqual(exp, got)
