@@ -3,11 +3,13 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
 import unittest
 from io import StringIO
+
 from ...table import Table
 
 
@@ -25,11 +27,11 @@ class TestWriteAutoFilter(unittest.TestCase):
     def test_write_auto_filter(self):
         """Test the _write_auto_filter() method"""
 
-        self.table.properties['autofilter'] = 'C3:F13'
+        self.table.properties["autofilter"] = "C3:F13"
 
         self.table._write_auto_filter()
 
         exp = """<autoFilter ref="C3:F13"/>"""
         got = self.fh.getvalue()
 
-        self.assertEqual(got, exp)
+        self.assertEqual(exp, got)
