@@ -3,11 +3,13 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
 import unittest
 from io import StringIO
+
 from ...table import Table
 
 
@@ -26,11 +28,11 @@ class TestWriteTableStyleInfo(unittest.TestCase):
         """Test the _write_table_style_info() method"""
 
         self.table.properties = {
-            'style': 'TableStyleMedium9',
-            'show_first_col': 0,
-            'show_last_col': 0,
-            'show_row_stripes': 1,
-            'show_col_stripes': 0,
+            "style": "TableStyleMedium9",
+            "show_first_col": 0,
+            "show_last_col": 0,
+            "show_row_stripes": 1,
+            "show_col_stripes": 0,
         }
 
         self.table._write_table_style_info()
@@ -38,4 +40,4 @@ class TestWriteTableStyleInfo(unittest.TestCase):
         exp = """<tableStyleInfo name="TableStyleMedium9" showFirstColumn="0" showLastColumn="0" showRowStripes="1" showColumnStripes="0"/>"""
         got = self.fh.getvalue()
 
-        self.assertEqual(got, exp)
+        self.assertEqual(exp, got)
