@@ -3,11 +3,13 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
 import unittest
 from io import StringIO
+
 from ...vml import Vml
 
 
@@ -25,9 +27,9 @@ class TestWriteDiv(unittest.TestCase):
     def test_write_div(self):
         """Test the _write_div() method"""
 
-        self.vml._write_div('left')
+        self.vml._write_div("left")
 
         exp = """<div style="text-align:left"></div>"""
         got = self.fh.getvalue()
 
-        self.assertEqual(got, exp)
+        self.assertEqual(exp, got)
