@@ -3,11 +3,13 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
 import unittest
 from io import StringIO
+
 from ...vml import Vml
 
 
@@ -30,4 +32,4 @@ class TestWriteVstroke(unittest.TestCase):
         exp = """<v:stroke joinstyle="miter"/>"""
         got = self.fh.getvalue()
 
-        self.assertEqual(got, exp)
+        self.assertEqual(exp, got)
