@@ -3,11 +3,13 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
 import unittest
 from io import StringIO
+
 from ...workbook import Workbook
 
 
@@ -25,32 +27,32 @@ class TestWriteSheet(unittest.TestCase):
     def test_write_sheet1(self):
         """Test the _write_sheet() method"""
 
-        self.workbook._write_sheet('Sheet1', 1, 0)
+        self.workbook._write_sheet("Sheet1", 1, 0)
 
         exp = """<sheet name="Sheet1" sheetId="1" r:id="rId1"/>"""
         got = self.fh.getvalue()
 
-        self.assertEqual(got, exp)
+        self.assertEqual(exp, got)
 
     def test_write_sheet2(self):
         """Test the _write_sheet() method"""
 
-        self.workbook._write_sheet('Sheet1', 1, 1)
+        self.workbook._write_sheet("Sheet1", 1, 1)
 
         exp = """<sheet name="Sheet1" sheetId="1" state="hidden" r:id="rId1"/>"""
         got = self.fh.getvalue()
 
-        self.assertEqual(got, exp)
+        self.assertEqual(exp, got)
 
     def test_write_sheet3(self):
         """Test the _write_sheet() method"""
 
-        self.workbook._write_sheet('Bits & Bobs', 1, 0)
+        self.workbook._write_sheet("Bits & Bobs", 1, 0)
 
         exp = """<sheet name="Bits &amp; Bobs" sheetId="1" r:id="rId1"/>"""
         got = self.fh.getvalue()
 
-        self.assertEqual(got, exp)
+        self.assertEqual(exp, got)
 
     def tearDown(self):
         self.workbook.fileclosed = 1
