@@ -3,11 +3,13 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
 import unittest
 from io import StringIO
+
 from ...worksheet import Worksheet
 
 
@@ -25,9 +27,9 @@ class TestWriteFilterColumn(unittest.TestCase):
     def test_write_filter_column(self):
         """Test the _write_filter_column() method"""
 
-        self.worksheet._write_filter_column(0, 1, ['East'])
+        self.worksheet._write_filter_column(0, 1, ["East"])
 
         exp = """<filterColumn colId="0"><filters><filter val="East"/></filters></filterColumn>"""
         got = self.fh.getvalue()
 
-        self.assertEqual(got, exp)
+        self.assertEqual(exp, got)
