@@ -3,11 +3,13 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
 import unittest
 from io import StringIO
+
 from ...worksheet import Worksheet
 
 
@@ -25,10 +27,10 @@ class TestWriteTabColor(unittest.TestCase):
     def test_write_tab_color(self):
         """Test the _write_tab_color() method"""
 
-        self.worksheet.set_tab_color('red')
+        self.worksheet.set_tab_color("red")
         self.worksheet._write_tab_color()
 
         exp = """<tabColor rgb="FFFF0000"/>"""
         got = self.fh.getvalue()
 
-        self.assertEqual(got, exp)
+        self.assertEqual(exp, got)
